==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/languages/sd.php <==
<?php

return [
    'Names' => [
        'aa' => 'افار',
        'ab' => 'ابقازیان',
        'ace' => 'اچائينيز',
        'ada' => 'ادنگمي',
        'ady' => 'اديگهي',
        'af' => 'آفريڪي',
        'agq' => 'اگهيم',
        'ain' => 'آئينو',
        'ak' => 'اڪان',
        'ale' => 'اليوٽ',
        'alt' => 'ڏکڻ التائي',
        'am' => 'امهاري',
        'an' => 'ارگني',
        'anp' => 'انجيڪا',
        'ar' => 'عربي',
        'arn' => 'ماپوچي',
        'arp' => 'اراپائو',
        'as' => 'آسامي',
        'asa' => 'اسو',
        'ast' => 'اسٽورين',
        'av' => 'اويرس',
        'awa' => 'اواڌي',
        'ay' => 'ایمارا',
        'az' => 'آزربائيجاني',
        'ba' => 'ڪينيڊا',
        'ban' => 'بالينيس',
        'bas' => 'باسا',
        'be' => 'بيلاروسي',
        'bem' => 'بيمبا',
        'bez' => 'بينا',
        'bg' => 'بلغاريائي',
        'bho' => 'ڀوجپوري',
        'bi' => 'بسلاما',
        'bin' => 'بني',
        'bla' => 'سڪسڪا',
        'bm' => 'بمبارا',
        'bn' => 'بنگلا',
        'bo' => 'تبيتائي',
        'br' => 'بريٽن',
        'brx' => 'بودو',
        'bs' => 'بوسنيائي',
        'bug' => 'بگنيز',
        'byn' => 'بلن',
        'ca' => 'ڪيٽالان',
        'ccp' => 'چمڪا',
        'ce' => 'چیچن',
        'ceb' => 'سبوانو',
        'cgg' => 'چگا',
        'ch' => 'چمورو',
        'chk' => 'چڪيز',
        'chm' => 'ماري',
        'cho' => 'چوڪ تو',
        'chr' => 'چروڪي',
        'chy' => 'چايان',
        'ckb' => 'مرڪزي ڪردش',
        'co' => 'ڪارسيڪائي',
        'crs' => 'سيسلوا ڪريئول فرانسي',
        'cs' => 'چيڪ',
        'cu' => 'چرچ سلاوی',
        'cv' => 'چو واش',
        'cy' => 'ويلش',
        'da' => 'ڊينش',
        'dak' => 'ڊڪوٽا',
        'dar' => 'ڊارگوا',
        'dav' => 'تائيتا',
        'de' => 'جرمن',
        'dgr' => 'داگرب',
        'dje' => 'زارما',
        'dsb' => 'لوئر سوربين',
        'dua' => 'ڊيولا',
        'dv' => 'دويهي',
        'dyo' => 'جولا فوني',
        'dz' => 'زونخا',
        'dzg' => 'دزاگا',
        'ebu' => 'ايمبيو',
        'ee' => 'ايو',
        'efi' => 'ايفڪ',
        'eka' => 'ايڪاجڪ',
        'el' => 'يوناني',
        'en' => 'انگريزي',
        'eo' => 'ايسپرانٽو',
        'es' => 'هسپانوي',
        'et' => 'ايستونائي',
        'eu' => 'باسق',
        'ewo' => 'اوانڊو',
        'fa' => 'فارسي',
        'ff' => 'فلاهه',
        'fi' => 'فنش',
        'fil' => 'فلپائني',
        'fj' => 'فجي',
        'fo' => 'فيروايس',
        'fon' => 'فون',
        'fr' => 'فرانسيسي',
        'fur' => 'فرائي لئين',
        'fy' => 'مغربي فريشن',
        'ga' => 'آئرش',
        'gaa' => 'گا',
        'gd' => 'اسڪاٽش گيلڪ',
        'gez' => 'جيز',
        'gil' => 'گلبرٽيز',
        'gl' => 'گليشئين',
        'gn' => 'گواراني',
        'gor' => 'گورنٽلو',
        'gsw' => 'سوئس جرمن',
        'gu' => 'گجراتي',
        'guz' => 'گشي',
        'gv' => 'مينڪس',
        'gwi' => 'گوچن',
        'ha' => 'هوسا',
        'haw' => 'هوائي',
        'he' => 'عبراني',
        'hi' => 'هندي',
        'hil' => 'هلي گيانان',
        'hmn' => 'مونگ',
        'hr' => 'ڪروشيائي',
        'hsb' => 'اپر سربيائي',
        'ht' => 'هيٽي ڪرولي',
        'hu' => 'هنگري',
        'hup' => 'هوپا',
        'hy' => 'ارماني',
        'hz' => 'هريرو',
        'ia' => 'انٽرلنگئا',
        'iba' => 'ايبن',
        'ibb' => 'ابيبيو',
        'id' => 'انڊونيشي',
        'ig' => 'اگبو',
        'ii' => 'سچوان يي',
        'ilo' => 'الوڪو',
        'inh' => 'انگش',
        'io' => 'ادو',
        'is' => 'آئيس لينڊڪ',
        'it' => 'اطالوي',
        'iu' => 'انو ڪتوت',
        'ja' => 'جاپاني',
        'jbo' => 'لوجبين',
        'jgo' => 'نغومبا',
        'jmc' => 'ميڪم',
        'jv' => 'جاونيز',
        'ka' => 'جارجيائي',
        'kab' => 'ڪبائل',
        'kac' => 'ڪچن',
        'kaj' => 'پوڪيپسي',
        'kam' => 'ڪئمبا',
        'kbd' => 'ڪبارڊيئن',
        'kcg' => 'تياپ',
        'kde' => 'مڪوندي',
        'kea' => 'ڪيبيو ويرڊيانو',
        'kfo' => 'ڪورو',
        'kha' => 'خاسي',
        'khq' => 'ڪيورا چني',
        'ki' => 'اڪويو',
        'kj' => 'ڪنياما',
        'kk' => 'قازق',
        'kkj' => 'ڪڪو',
        'kl' => 'ڪالا ليسٽ',
        'kln' => 'ڪيلين جن',
        'km' => 'خمر',
        'kmb' => 'ڪمبونڊو',
        'kn' => 'ڪناڊا',
        'ko' => 'ڪوريائي',
        'kok' => 'ڪونڪي',
        'kpe' => 'ڪپيل',
        'kr' => 'ڪنوري',
        'krc' => 'ڪراچي بالڪر',
        'krl' => 'ڪريلئين',
        'kru' => 'ڪورخ',
        'ks' => 'ڪشميري',
        'ksb' => 'شمبالا',
        'ksf' => 'بافيا',
        'ksh' => 'ڪلونئين',
        'ku' => 'ڪردي',
        'kum' => 'ڪومڪ',
        'kv' => 'ڪومي',
        'kw' => 'ڪورنش',
        'ky' => 'ڪرغيز',
        'la' => 'لاطيني',
        'lad' => 'لڊينو',
        'lag' => 'لانگي',
        'lb' => 'لگزمبرگ',
        'lez' => 'ليزگهين',
        'lg' => 'گاندا',
        'li' => 'لمبرگش',
        'lkt' => 'لڪوٽا',
        'ln' => 'لنگالا',
        'lo' => 'لائو',
        'loz' => 'لوزي',
        'lrc' => 'اتر لوري',
        'lt' => 'ليٿونيائي',
        'lu' => 'لوبا-ڪتانگا',
        'lua' => 'لوبا-لولوا',
        'lun' => 'لنڊا',
        'luo' => 'لو',
        'lus' => 'ميزو',
        'luy' => 'لوهيا',
        'lv' => 'لاتوين',
        'mad' => 'مدورائي',
        'mag' => 'مگاهي',
        'mai' => 'ميٿلي',
        'mak' => 'مڪاسر',
        'mas' => 'مسائي',
        'mdf' => 'موڪشا',
        'men' => 'مينڊي',
        'mer' => 'ميرو',
        'mfe' => 'موریسیین',
        'mg' => 'ملاگاسي',
        'mgh' => 'مخووا ميتو',
        'mgo' => 'ميتا',
        'mh' => 'مارشليز',
        'mi' => 'مائوري',
        'mic' => 'ميڪ مڪ',
        'min' => 'مناڪابوا',
        'mk' => 'ميسي ڊونيائي',
        'ml' => 'مليالم',
        'mn' => 'منگولي',
        'mni' => 'ماني پوري',
        'moh' => 'موهاڪ',
        'mos' => 'موسي',
        'mr' => 'مراٺي',
        'ms' => 'ملي',
        'mt' => 'مالٽي',
        'mua' => 'من دانگ',
        'mus' => 'ڪريڪ',
        'mwl' => 'مرانڊيز',
        'my' => 'برمي',
        'myv' => 'ايريزيا',
        'mzn' => 'مزيندراني',
        'na' => 'نائو',
        'nap' => 'نيپولٽن',
        'naq' => 'ناما',
        'nb' => 'نارويائي بوڪمال',
        'nd' => 'اتر دبيلي',
        'nds' => 'لو جرمن',
        'ne' => 'نيپالي',
        'new' => 'نيواري',
        'ng' => 'ڊونگا',
        'nia' => 'نياس',
        'niu' => 'نووي',
        'nl' => 'ڊچ',
        'nmg' => 'ڪويسيو',
        'nn' => 'نارويائي نيوناسڪ',
        'nnh' => 'نغيمبون',
        'nog' => 'نوگائي',
        'nqo' => 'نڪو',
        'nr' => 'ڏکڻ دبيلي',
        'nso' => 'اتر سوٿو',
        'nus' => 'نيور',
        'nv' => 'نواجو',
        'ny' => 'نيانجا',
        'nyn' => 'نايانڪول',
        'oc' => 'آڪسيٽن',
        'om' => 'اورومو',
        'or' => 'اوڊيا',
        'os' => 'اوسيٽڪ',
        'pa' => 'پنجابي',
        'pag' => 'پانگا سينان',
        'pam' => 'پيم پينگا',
        'pap' => 'پاپي امينٽو',
        'pau' => 'پلون',
        'pcm' => 'نائيجرين پجن',
        'pl' => 'پولش',
        'prg' => 'پرشن',
        'ps' => 'پشتو',
        'pt' => 'پورٽگليز',
        'qu' => 'ڪيچوا',
        'quc' => 'ڪچي',
        'rap' => 'ريپنوئي',
        'rar' => 'ريرو ٽينگو',
        'rm' => 'رومانش',
        'rn' => 'رونڊي',
        'ro' => 'روماني',
        'rof' => 'رومبو',
        'ru' => 'روسي',
        'rup' => 'ارومينين',
        'rw' => 'ڪنيار وانڊا',
        'rwk' => 'روا',
        'sa' => 'سنسڪرت',
        'sad' => 'سنداوي',
        'sah' => 'ساخا',
        'saq' => 'سيمبورو',
        'sat' => 'سنتالي',
        'sba' => 'نغمبي',
        'sbp' => 'سانگوو',
        'sc' => 'سارڊيني',
        'scn' => 'سسلي',
        'sco' => 'اسڪاٽس',
        'sd' => 'سنڌي',
        'se' => 'اتر سامي',
        'seh' => 'سينا',
        'ses' => 'ڪيورابورو سيني',
        'sg' => 'سانگو',
        'shi' => 'تيچل هاتي',
        'shn' => 'شان',
        'si' => 'سنهالا',
        'sk' => 'سلواڪي',
        'sl' => 'سلوويني',
        'sm' => 'سموئا',
        'sma' => 'ڏکڻ سامي',
        'smj' => 'لولي سامي',
        'smn' => 'اناري سامي',
        'sms' => 'اسڪاٽ سامي',
        'sn' => 'شونا',
        'snk' => 'سونينڪي',
        'so' => 'سومالي',
        'sq' => 'الباني',
        'sr' => 'سربيائي',
        'srn' => 'سرانن تانگو',
        'ss' => 'سواتي',
        'ssy' => 'سهو',
        'st' => 'ڏکڻ سوٿي',
        'su' => 'سوڊاني',
        'suk' => 'سڪوما',
        'sv' => 'سويڊش',
        'sw' => 'سواحيلي',
        'swb' => 'ڪمورين',
        'syr' => 'شامي',
        'ta' => 'تامل',
        'te' => 'تلگو',
        'tem' => 'تمني',
        'teo' => 'تيسو',
        'tet' => 'تيتم',
        'tg' => 'تاجڪ',
        'th' => 'ٿائي',
        'ti' => 'تگرينيائي',
        'tig' => 'تگري',
        'tk' => 'ترڪمين',
        'tlh' => 'ڪلون',
        'tn' => 'تسوانا',
        'to' => 'تونگن',
        'tpi' => 'تاڪ پسن',
        'tr' => 'ترڪش',
        'trv' => 'تاروڪو',
        'ts' => 'سونگا',
        'tt' => 'تاتار',
        'tum' => 'تمبوڪا',
        'tvl' => 'توالو',
        'twq' => 'تساوڪي',
        'ty' => 'تاهيتي',
        'tyv' => 'تووينيائي',
        'tzm' => 'وچ اٽلس تمازائيٽ',
        'udm' => 'ادمورتيا',
        'ug' => 'يوغور',
        'uk' => 'يوڪراني',
        'umb' => 'اومبنڊو',
        'ur' => 'اردو',
        'uz' => 'ازبڪ',
        'vai' => 'يا',
        've' => 'وينڊا',
        'vi' => 'ويتنامي',
        'vo' => 'والپڪ',
        'vun' => 'ونجو',
        'wa' => 'ولون',
        'wae' => 'والسر',
        'wal' => 'وولايٽا',
        'war' => 'واري',
        'wo' => 'وولوف',
        'xal' => 'ڪيلمڪ',
        'xh' => 'زھوسا',
        'xog' => 'سوگا',
        'yav' => 'يانگ بين',
        'ybb' => 'ييمبا',
        'yi' => 'يدش',
        'yo' => 'يوروبا',
        'yue' => 'ڪينٽونيز',
        'zgh' => 'معياري مراڪشي تامازائيٽ',
        'zh' => 'چيني',
        'zu' => 'زولو',
        'zun' => 'زوني',
        'zza' => 'زازا',
    ],
    'LocalizedNames' => [
        'ar_001' => 'جديد معياري عربي',
        'de_AT' => 'آسٽريائي جرمن',
        'de_CH' => 'سوئس هائي جرمن',
        'en_AU' => 'آسٽريليائي انگريزي',
        'en_CA' => 'ڪينيڊيائي انگريزي',
        'en_GB' => 'برطانوي انگريزي',
        'en_US' => 'آمريڪي انگريزي',
        'es_419' => 'لاطيني آمريڪي اسپينش',
        'es_ES' => 'يورپي اسپيني',
        'es_MX' => 'ميڪسيڪين اسپيني',
        'fa_AF' => 'دري',
        'fr_CA' => 'ڪينيڊيائي فرانسيسي',
        'fr_CH' => 'سوئس فرانسيسي',
        'nl_BE' => 'فليمش',
        'pt_BR' => 'برازيلي پرتگالي',
        'pt_PT' => 'يورپي پرتگالي',
        'ro_MD' => 'مالديوي',
        'sw_CD' => 'ڪونگو سواحيلي',
        'zh_Hant' => 'روايتي چيني',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/languages/sd.php <==
<?php

return [
    'Names' => [
        'aa' => 'افار',
        'ab' => 'ابقازیان',
        'ace' => 'اچائينيز',
        'ada' => 'ادنگمي',
        'ady' => 'اديگهي',
        'af' => 'آفريڪي',
        'agq' => 'اگهيم',
        'ain' => 'آئينو',
        'ak' => 'اڪان',
        'ale' => 'اليوٽ',
        'alt' => 'ڏکڻ التائي',
        'am' => 'امهاري',
        'an' => 'ارگني',
        'ann' => 'اوبولو',
        'anp' => 'انجيڪا',
        'ar' => 'عربي',
        'arn' => 'ماپوچي',
        'arp' => 'اراپائو',
        'ars' => 'نجدي عربي',
        'as' => 'آسامي',
        'asa' => 'اسو',
        'ast' => 'اسٽورين',
        'atj' => 'اٽيڪاميڪو',
        'av' => 'اويرس',
        'awa' => 'اواڌي',
        'ay' => 'ایمارا',
        'az' => 'آزربائيجاني',
        'ba' => 'ڪينيڊا',
        'ban' => 'بالينيس',
        'bas' => 'باسا',
        'be' => 'بيلاروسي',
        'bem' => 'بيمبا',
        'bez' => 'بينا',
        'bg' => 'بلغاريائي',
        'bho' => 'ڀوجپوري',
        'bi' => 'بسلاما',
        'bin' => 'بني',
        'bla' => 'سڪسڪا',
        'bm' => 'بمبارا',
        'bn' => 'بنگلا',
        'bo' => 'تبيتائي',
        'br' => 'بريٽن',
        'brx' => 'بودو',
        'bs' => 'بوسنيائي',
        'bug' => 'بگنيز',
        'byn' => 'بلن',
        'ca' => 'ڪيٽالان',
        'cay' => 'ڪايوگا',
        'ccp' => 'چمڪا',
        'ce' => 'چیچن',
        'ceb' => 'سبوانو',
        'cgg' => 'چگا',
        'ch' => 'چمورو',
        'chk' => 'چڪيز',
        'chm' => 'ماري',
        'cho' => 'چوڪ تو',
        'chp' => 'چائپائن',
        'chr' => 'چروڪي',
        'chy' => 'چايان',
        'ckb' => 'مرڪزي ڪردش',
        'clc' => 'چلڪوٽن',
        'co' => 'ڪارسيڪائي',
        'crg' => 'ميچيف',
        'crj' => 'ڏکڻ اڀرندو ڪري',
        'crk' => 'پلينز ڪري',
        'crl' => 'اترين اوڀر ڪري',
        'crm' => 'موس ڪري',
        'crr' => 'ڪيرولينا الگانڪويئن',
        'crs' => 'سيسلوا ڪريئول فرانسي',
        'cs' => 'چيڪ',
        'csw' => 'سوامپي ڪري',
        'cu' => 'چرچ سلاوی',
        'cv' => 'چو واش',
        'cy' => 'ويلش',
        'da' => 'ڊينش',
        'dak' => 'ڊڪوٽا',
        'dar' => 'ڊارگوا',
        'dav' => 'تائيتا',
        'de' => 'جرمن',
        'dgr' => 'داگرب',
        'dje' => 'زارما',
        'doi' => 'ڊوگري',
        'dsb' => 'لوئر سوربين',
        'dua' => 'ڊيولا',
        'dv' => 'دويهي',
        'dyo' => 'جولا فوني',
        'dz' => 'زونخا',
        'dzg' => 'دزاگا',
        'ebu' => 'ايمبيو',
        'ee' => 'ايو',
        'efi' => 'ايفڪ',
        'eka' => 'ايڪاجڪ',
        'el' => 'يوناني',
        'en' => 'انگريزي',
        'eo' => 'ايسپرانٽو',
        'es' => 'هسپانوي',
        'et' => 'ايستونائي',
        'eu' => 'باسق',
        'ewo' => 'اوانڊو',
        'fa' => 'فارسي',
        'ff' => 'فلاهه',
        'fi' => 'فنش',
        'fil' => 'فلپائني',
        'fj' => 'فجي',
        'fo' => 'فيروايس',
        'fon' => 'فون',
        'fr' => 'فرانسيسي',
        'frc' => 'ڪيجن فرانسيسي',
        'frr' => 'اترين فريسين',
        'fur' => 'فرائي لئين',
        'fy' => 'مغربي فريشن',
        'ga' => 'آئرش',
        'gaa' => 'گا',
        'gd' => 'اسڪاٽش گيلڪ',
        'gez' => 'جيز',
        'gil' => 'گلبرٽيز',
        'gl' => 'گليشئين',
        'gn' => 'گواراني',
        'gor' => 'گورنٽلو',
        'gsw' => 'سوئس جرمن',
        'gu' => 'گجراتي',
        'guz' => 'گشي',
        'gv' => 'مينڪس',
        'gwi' => 'گوچن',
        'ha' => 'هوسا',
        'hai' => 'ھائيڊا',
        'haw' => 'هوائي',
        'hax' => 'ڏاکڻي ھائڊا',
        'he' => 'عبراني',
        'hi' => 'هندي',
        'hil' => 'هلي گيانان',
        'hmn' => 'مونگ',
        'hr' => 'ڪروشيائي',
        'hsb' => 'اپر سربيائي',
        'ht' => 'هيٽي ڪرولي',
        'hu' => 'هنگري',
        'hup' => 'هوپا',
        'hur' => 'ھاڪملم',
        'hy' => 'ارماني',
        'hz' => 'هريرو',
        'ia' => 'انٽرلنگئا',
        'iba' => 'ايبن',
        'ibb' => 'ابيبيو',
        'id' => 'انڊونيشي',
        'ig' => 'اگبو',
        'ii' => 'سچوان يي',
        'ikt' => 'مغربي ڪينيڊين انوڪٽيٽ',
        'ilo' => 'الوڪو',
        'inh' => 'انگش',
        'io' => 'ادو',
        'is' => 'آئيس لينڊڪ',
        'it' => 'اطالوي',
        'iu' => 'انو ڪتوت',
        'ja' => 'جاپاني',
        'jbo' => 'لوجبين',
        'jgo' => 'نغومبا',
        'jmc' => 'ميڪم',
        'jv' => 'جاونيز',
        'ka' => 'جارجيائي',
        'kab' => 'ڪبائل',
        'kac' => 'ڪچن',
        'kaj' => 'پوڪيپسي',
        'kam' => 'ڪئمبا',
        'kbd' => 'ڪبارڊيئن',
        'kcg' => 'تياپ',
        'kde' => 'مڪوندي',
        'kea' => 'ڪيبيو ويرڊيانو',
        'kfo' => 'ڪورو',
        'kgp' => 'ڪئينگينگ',
        'kha' => 'خاسي',
        'khq' => 'ڪيورا چني',
        'ki' => 'اڪويو',
        'kj' => 'ڪنياما',
        'kk' => 'قازق',
        'kkj' => 'ڪڪو',
        'kl' => 'ڪالا ليسٽ',
        'kln' => 'ڪيلين جن',
        'km' => 'خمر',
        'kmb' => 'ڪنمبونڊو',
        'kn' => 'ڪناڊا',
        'ko' => 'ڪوريائي',
        'kok' => 'ڪونڪي',
        'kpe' => 'ڪپيل',
        'kr' => 'ڪنوري',
        'krc' => 'ڪراچي بالڪر',
        'krl' => 'ڪريلئين',
        'kru' => 'ڪورخ',
        'ks' => 'ڪشميري',
        'ksb' => 'شمبالا',
        'ksf' => 'بافيا',
        'ksh' => 'ڪلونئين',
        'ku' => 'ڪردي',
        'kum' => 'ڪومڪ',
        'kv' => 'ڪومي',
        'kw' => 'ڪورنش',
        'kwk' => 'ڪئاڪ ولا',
        'ky' => 'ڪرغيز',
        'la' => 'لاطيني',
        'lad' => 'لڊينو',
        'lag' => 'لانگي',
        'lb' => 'لگزمبرگ',
        'lez' => 'ليزگهين',
        'lg' => 'گاندا',
        'li' => 'لمبرگش',
        'lil' => 'ليلوئيٽ',
        'lkt' => 'لڪوٽا',
        'ln' => 'لنگالا',
        'lo' => 'لائو',
        'lou' => 'لوئيزيانا ڪريئول',
        'loz' => 'لوزي',
        'lrc' => 'اتر لوري',
        'lsm' => 'ساميا',
        'lt' => 'ليٿونيائي',
        'lu' => 'لوبا-ڪتانگا',
        'lua' => 'لوبا-لولوا',
        'lun' => 'لنڊا',
        'luo' => 'لو',
        'lus' => 'ميزو',
        'luy' => 'لوهيا',
        'lv' => 'لاتوين',
        'mad' => 'مدورائي',
        'mag' => 'مگاهي',
        'mai' => 'ميٿلي',
        'mak' => 'مڪاسر',
        'mas' => 'مسائي',
        'mdf' => 'موڪشا',
        'men' => 'مينڊي',
        'mer' => 'ميرو',
        'mfe' => 'موریسیین',
        'mg' => 'ملاگاسي',
        'mgh' => 'مخووا ميتو',
        'mgo' => 'ميتا',
        'mh' => 'مارشليز',
        'mi' => 'مائوري',
        'mic' => 'ميڪ مڪ',
        'min' => 'مناڪابوا',
        'mk' => 'ميسي ڊونيائي',
        'ml' => 'مليالم',
        'mn' => 'منگولي',
        'mni' => 'ماني پوري',
        'moe' => 'انو آئيمن',
        'moh' => 'موهاڪ',
        'mos' => 'موسي',
        'mr' => 'مراٺي',
        'ms' => 'ملي',
        'mt' => 'مالٽي',
        'mua' => 'من دانگ',
        'mus' => 'ڪريڪ',
        'mwl' => 'مرانڊيز',
        'my' => 'برمي',
        'myv' => 'ايريزيا',
        'mzn' => 'مزيندراني',
        'na' => 'نائو',
        'nap' => 'نيپولٽن',
        'naq' => 'ناما',
        'nb' => 'نارويائي بوڪمال',
        'nd' => 'اتر دبيلي',
        'nds' => 'لو جرمن',
        'ne' => 'نيپالي',
        'new' => 'نيواري',
        'ng' => 'ڊونگا',
        'nia' => 'نياس',
        'niu' => 'نووي',
        'nl' => 'ڊچ',
        'nmg' => 'ڪويسيو',
        'nn' => 'نارويائي نيوناسڪ',
        'nnh' => 'نغيمبون',
        'no' => 'نارويجيائي',
        'nog' => 'نوگائي',
        'nqo' => 'نڪو',
        'nr' => 'ڏکڻ دبيلي',
        'nso' => 'اتر سوٿو',
        'nus' => 'نيور',
        'nv' => 'نواجو',
        'ny' => 'نيانجا',
        'nyn' => 'نايانڪول',
        'oc' => 'آڪسيٽن',
        'ojb' => 'اتر الھندي اوجيبوا',
        'ojc' => 'وچولي اوجيبوي',
        'ojs' => 'اوجي ڪري',
        'ojw' => 'مغربي اوجيبو',
        'oka' => 'اوڪاناگن',
        'om' => 'اورومو',
        'or' => 'اوڊيا',
        'os' => 'اوسيٽڪ',
        'pa' => 'پنجابي',
        'pag' => 'پانگا سينان',
        'pam' => 'پيم پينگا',
        'pap' => 'پاپي امينٽو',
        'pau' => 'پلون',
        'pcm' => 'نائيجرين پجن',
        'pis' => 'پائجن',
        'pl' => 'پولش',
        'pqm' => 'ماليسيٽ پاسماڪئوڊي',
        'prg' => 'پرشن',
        'ps' => 'پشتو',
        'pt' => 'پورٽگليز',
        'qu' => 'ڪيچوا',
        'quc' => 'ڪچي',
        'rap' => 'ريپنوئي',
        'rar' => 'ريرو ٽينگو',
        'rhg' => 'روھنگيا',
        'rm' => 'رومانش',
        'rn' => 'رونڊي',
        'ro' => 'روماني',
        'rof' => 'رومبو',
        'ru' => 'روسي',
        'rup' => 'ارومينين',
        'rw' => 'ڪنيار وانڊا',
        'rwk' => 'روا',
        'sa' => 'سنسڪرت',
        'sad' => 'سنداوي',
        'sah' => 'ساخا',
        'saq' => 'سيمبورو',
        'sat' => 'سنتالي',
        'sba' => 'نغمبي',
        'sbp' => 'سانگوو',
        'sc' => 'سارڊيني',
        'scn' => 'سسلي',
        'sco' => 'اسڪاٽس',
        'sd' => 'سنڌي',
        'se' => 'اتر سامي',
        'seh' => 'سينا',
        'ses' => 'ڪيورابورو سيني',
        'sg' => 'سانگو',
        'shi' => 'تيچل هاتي',
        'shn' => 'شان',
        'si' => 'سنهالا',
        'sk' => 'سلواڪي',
        'sl' => 'سلوويني',
        'slh' => 'ڏاکڻي لشوٽسيڊ',
        'sm' => 'سموئا',
        'sma' => 'ڏکڻ سامي',
        'smj' => 'لولي سامي',
        'smn' => 'اناري سامي',
        'sms' => 'اسڪاٽ سامي',
        'sn' => 'شونا',
        'snk' => 'سونينڪي',
        'so' => 'سومالي',
        'sq' => 'الباني',
        'sr' => 'سربيائي',
        'srn' => 'سرانن تانگو',
        'ss' => 'سواتي',
        'ssy' => 'سهو',
        'st' => 'ڏکڻ سوٿي',
        'str' => 'اسٽريٽ سليش',
        'su' => 'سوڊاني',
        'suk' => 'سڪوما',
        'sv' => 'سويڊش',
        'sw' => 'سواحيلي',
        'swb' => 'ڪمورين',
        'syr' => 'شامي',
        'ta' => 'تامل',
        'tce' => 'ڏاکڻي ٽچون',
        'te' => 'تلگو',
        'tem' => 'تمني',
        'teo' => 'تيسو',
        'tet' => 'تيتم',
        'tg' => 'تاجڪ',
        'tgx' => 'ٽئگِش',
        'th' => 'ٿائي',
        'tht' => 'ٽهلٽن',
        'ti' => 'تگرينيائي',
        'tig' => 'تگري',
        'tk' => 'ترڪمين',
        'tlh' => 'ڪلون',
        'tli' => 'ٽِلنگٽ',
        'tn' => 'تسوانا',
        'to' => 'تونگن',
        'tok' => 'توڪي پونا',
        'tpi' => 'تاڪ پسن',
        'tr' => 'ترڪش',
        'trv' => 'تاروڪو',
        'ts' => 'سونگا',
        'tt' => 'تاتار',
        'ttm' => 'اترين ٽچون',
        'tum' => 'تمبوڪا',
        'tvl' => 'توالو',
        'twq' => 'تساوڪي',
        'ty' => 'تاهيتي',
        'tyv' => 'تووينيائي',
        'tzm' => 'وچ اٽلس تمازائيٽ',
        'udm' => 'ادمرت',
        'ug' => 'يوغور',
        'uk' => 'يوڪراني',
        'umb' => 'اومبنڊو',
        'ur' => 'اردو',
        'uz' => 'ازبڪ',
        'vai' => 'يا',
        've' => 'وينڊا',
        'vi' => 'ويتنامي',
        'vo' => 'والپڪ',
        'vun' => 'ونجو',
        'wa' => 'ولون',
        'wae' => 'والسر',
        'wal' => 'وولايٽا',
        'war' => 'واري',
        'wo' => 'وولوف',
        'wuu' => 'وو چيني',
        'xal' => 'ڪيلمڪ',
        'xh' => 'زھوسا',
        'xog' => 'سوگا',
        'yav' => 'يانگ بين',
        'ybb' => 'ييمبا',
        'yi' => 'يدش',
        'yo' => 'يوروبا',
        'yrl' => 'نھين گاٽو',
        'yue' => 'ڪينٽونيز',
        'zgh' => 'معياري مراڪشي تامازائيٽ',
        'zh' => 'چيني',
        'zu' => 'زولو',
        'zun' => 'زوني',
        'zza' => 'زازا',
    ],
    'LocalizedNames' => [
        'ar_001' => 'جديد معياري عربي',
        'de_AT' => 'آسٽريائي جرمن',
        'de_CH' => 'سوئس هائي جرمن',
        'en_AU' => 'آسٽريليائي انگريزي',
        'en_CA' => 'ڪينيڊيائي انگريزي',
        'en_GB' => 'برطانوي انگريزي',
        'en_US' => 'آمريڪي انگريزي',
        'es_419' => 'لاطيني آمريڪي اسپينش',
        'es_ES' => 'يورپي اسپيني',
        'es_MX' => 'ميڪسيڪين اسپيني',
        'fa_AF' => 'دري',
        'fr_CA' => 'ڪينيڊيائي فرانسيسي',
        'fr_CH' => 'سوئس فرانسيسي',
        'nl_BE' => 'فليمش',
        'pt_BR' => 'برازيلي پرتگالي',
        'pt_PT' => 'يورپي پرتگالي',
        'ro_MD' => 'مالديوي',
        'sw_CD' => 'ڪونگو سواحيلي',
        'zh_Hant' => 'روايتي چيني',
    ],
];
